# CHANGELOG

<!-- version list -->

## v0.1.0-alpha.4 (2025-07-28)

### Bug Fixes

- Graceful not found message when node_id does not exist in graph [SC-34003]
  ([#13](https://github.com/aptible/unpage/pull/13),
  [`e2393d2`](https://github.com/aptible/unpage/commit/e2393d2ff1a2f8c7a854a9068b87a820f8adfece))

### Documentation

- [sc-33936] [sc-33939] [sc-34001] Add Core Concepts and Command Reference docs
  ([#16](https://github.com/aptible/unpage/pull/16),
  [`b3c2f8f`](https://github.com/aptible/unpage/commit/b3c2f8feb859ed807f6cfb44f98db3b3ef89404c))

- Getting started - v1 ([#10](https://github.com/aptible/unpage/pull/10),
  [`672fac9`](https://github.com/aptible/unpage/commit/672fac9e7fd439a3d33ada6fa1012d2064d2e28e))


## v0.1.0-alpha.3 (2025-07-25)

### Bug Fixes

- Pin numba to also bring up llvmlite ([#12](https://github.com/aptible/unpage/pull/12),
  [`4649884`](https://github.com/aptible/unpage/commit/46498848e0bd9e5020ed3ad6c3a6bdbcc502bb7e))


## v0.1.0-alpha.2 (2025-07-25)

### Features

- Start on an Unpage mascot ([#8](https://github.com/aptible/unpage/pull/8),
  [`7f41a4d`](https://github.com/aptible/unpage/commit/7f41a4d3c42fde8f9bc3c04a6103e20c927855c3))


## v0.1.0-alpha.1 (2025-07-25)

### Features

- Add support for disabling telemetry ([#7](https://github.com/aptible/unpage/pull/7),
  [`037798c`](https://github.com/aptible/unpage/commit/037798cbaec8ded81b316762421f00ba3c2b1bae))


## v0.0.1-alpha.1 (2025-07-25)

- Initial Release
